#

##

###

###

##

##

##

##

    	nocturnal

    	on
    		sesssion 1
    			docker compose up -d; sleep 5; docker exec -it nocturnal.1 bash
    			. /habitat/_controls/build_1.sh

    		sesssion 2
    			docker exec -it nocturnal.1 bash;
    			. /habitat/_controls/build_2.sh

    	off
    		docker container stop nocturnal.1; docker container rm nocturnal.1;

    	status
    		cd /habitat/parties/nocturnal/_status/

    		python3 /habitat/parties/nocturnal/_status/status.proc.py

    	publishing
    		python3 /habitat/parties/nocturnal/_status/status.proc.py

    		git add --all; git commit -m "save"; git tag 1.3.2

    		(pip install poetry && cd /habitat && rm -rf dist && poetry build --format sdist --verbose && chmod -R 777 /habitat)

    		poetry publish --verbose

    		du -sh /habitat/dist

    	important
    		@ keys
    			@ enzymes